@@ -332,7 +332,7 @@ int board_parse_line(const char *line, board *b, char handsep, char suitsep)
 	seat se = west;
 	int su = spade;
 	while (*c && *c != '\n') {
-		rank ra;
+		int ra;
 		if (*c == suitsep) {
 			su--;
 			if (su < 0)
@@ -366,7 +366,7 @@ board_load (window_board_t *win, char *fname)
 
 	int ret;
 	if (!strncmp(buf, "pn|", 3) || !strncmp(buf, "vg|", 3) ||
-	    !strncmp(buf, "st|", 3)) {
+	    !strncmp(buf, "st|", 3) || !strncmp(buf, "qx|", 3)) {
 		ret = board_parse_lin (win, buf, f);
 	} else {
 		board *b = board_new (win->n_boards + 1);
@@ -769,8 +769,10 @@ retry_save:
 
 /* open on bridgebase.com */
 
-static seat_lc[] = { 0, 'w', 'n', 'e', 's' };
-static vuln_lc[] = { 'o', 'n', 'e', 'b' };
+/* non-lin interface
+static char seat_lc[] = { 0, 'w', 'n', 'e', 's' };
+static char vuln_lc[] = { 'o', 'n', 'e', 'b' };
+*/
 
 void
 on_menu_file_web_activate ()
